package org.kar.karso.api;

import java.sql.Timestamp;
import java.time.OffsetDateTime;
import java.time.ZoneOffset;
import java.util.List;

import org.kar.archidata.dataAccess.DataAccess;
import org.kar.archidata.dataAccess.QueryAnd;
import org.kar.archidata.dataAccess.QueryCondition;
import org.kar.archidata.dataAccess.options.Condition;
import org.kar.archidata.exception.DataAccessException;
import org.kar.archidata.exception.InputException;
import org.kar.karso.model.ApplicationToken;
import org.kar.karso.model.CreateTokenRequest;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import jakarta.annotation.security.RolesAllowed;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.DELETE;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.Context;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.SecurityContext;

@Path("/application_token")
@Produces(MediaType.APPLICATION_JSON)
public class ApplicationTokenResource {
	private static final Logger LOGGER = LoggerFactory.getLogger(ApplicationTokenResource.class);

	public ApplicationTokenResource() {}

	////////////////////////////////////////////////////////////////////////////////////////
	//
	//   Generic /application_token/{applicationId}
	//
	////////////////////////////////////////////////////////////////////////////////////////

	@GET
	@Path("{applicationId}")
	@RolesAllowed(value = { "ADMIN" })
	public List<ApplicationToken> gets(
			@Context final SecurityContext sc,
			@PathParam("applicationId") final Long applicationId) throws Exception {
		final List<ApplicationToken> values = DataAccess.getsWhere(ApplicationToken.class,
				new Condition(new QueryCondition("parentId", "=", applicationId)));
		// clean all tokens this is a secret:
		for (final ApplicationToken elem : values) {
			elem.token = null;
		}
		return values;
	}

	@DELETE
	@Path("{applicationId}/{tokenId}")
	@RolesAllowed(value = { "ADMIN" })
	public void remove(
			@Context final SecurityContext sc,
			@PathParam("applicationId") final Long applicationId,
			@PathParam("tokenId") final Integer tokenId) throws Exception {
		final long nbRemoved = DataAccess.deleteWhere(ApplicationToken.class,
				new Condition(new QueryAnd(new QueryCondition("parentId", "=", applicationId),
						new QueryCondition("id", "=", tokenId))));
		if (nbRemoved == 0) {
			throw new DataAccessException("Fail to remove token");
		}
	}

	private String multipartCorrection(final String data) {
		if (data == null) {
			return null;
		}
		if (data.isEmpty()) {
			return null;
		}
		if (data.contentEquals("null")) {
			return null;
		}
		return data;
	}

	static String randomToken() {
		final int len = 48;
		final String valid_element = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvxyz0123456789#_@-~*!?";
		// creating a StringBuffer size of AlphaNumericStr
		final StringBuilder out = new StringBuilder(len);
		int iii;
		for (iii = 0; iii < len; iii++) {
			//generating a random number using math.random()
			final int ch = (int) (valid_element.length() * Math.random());
			//adding Random character one by one at the end of s
			out.append(valid_element.charAt(ch));
		}
		return out.toString();
	}

	@POST
	@Path("{applicationId}/create")
	@RolesAllowed("ADMIN")
	@Consumes(MediaType.APPLICATION_JSON)
	public ApplicationToken create(
			@Context final SecurityContext sc,
			@PathParam("applicationId") final Long applicationId,
			final CreateTokenRequest request) throws Exception {
		LOGGER.info("get user application TOKEN: app='{}' user='???'", applicationId);
		// correct input string stream :
		final String name = multipartCorrection(request.name);
		//validity = multipartCorrection(validity);
		LOGGER.debug("create a new token...");
		if (applicationId == null) {
			throw new InputException("applicationId", "can not be null");
		}
		final int maximum = 365 * 5;
		Integer validity = request.validity;
		if (validity == null || validity < 0 || validity > maximum) {
			validity = maximum;
		}
		LOGGER.warn("validity= {}", validity);
		// todo: set validity timestamp ...
		// TODO: check if application exist ...
		ApplicationToken token = new ApplicationToken();
		token.token = randomToken();
		token.name = multipartCorrection(name);
		token.parentId = applicationId;
		final OffsetDateTime now = OffsetDateTime.now(ZoneOffset.UTC);
		LOGGER.warn("Check Timestamp now   = {}", now);
		token.endValidityTime = Timestamp.from(now.plusDays(validity).toInstant());
		LOGGER.warn("token.endValidityTime = {}", token.endValidityTime);

		// insert in the BDD
		token = DataAccess.insert(token);
		// here we return the token to permit to the user to see it to set it in the application.
		return token;
	}
	/*
	Cannot find a deserializer for non-concrete Map type [map type; class jakarta.ws.rs.core.MultivaluedMap, [simple type, class java.lang.String] -> [collection type; class java.util.List, contains [simple type, class java.lang.String]]]
	at [Source: (org.glassfish.jersey.message.internal.ReaderInterceptorExecutor$UnCloseableInputStream); line: 1, column: 1]
	 */
}
