package org.kar.karso.api;

import java.security.interfaces.RSAPublicKey;
import java.util.Base64;

import org.kar.archidata.tools.JWTWrapper;
import org.kar.archidata.tools.JWTWrapper.PublicKey;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.nimbusds.jose.JOSEException;

import jakarta.annotation.security.RolesAllowed;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;

@Path("/public_key")
@Produces(MediaType.APPLICATION_JSON)
public class PublicKeyResource {
	private static final Logger LOGGER = LoggerFactory.getLogger(PublicKeyResource.class);

	public PublicKeyResource() {

	}

	// This is for java server that use the same implementation
	// curl http://localhost:9993/public_key
	@GET
	@RolesAllowed(value = { "APPLICATION" })
	public PublicKey getKey() {
		return new PublicKey(JWTWrapper.getPublicKeyJson());
	}

	// This is for common other interface that support public PEM stream.
	// curl http://localhost:9993/public_key/pem
	@GET
	@Path("/pem")
	@RolesAllowed(value = { "APPLICATION" })
	public String getKeyPem() throws JOSEException {
		final RSAPublicKey keyPub = JWTWrapper.getPublicKeyJava();
		final byte[] data = keyPub.getEncoded();
		final String base64encoded = new String(Base64.getEncoder().encode(data));
		return "-----BEGIN PUBLIC KEY-----\n" + base64encoded + "\n-----END PUBLIC KEY-----\n";
	}
}
