package org.kar.karso.api;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.kar.archidata.annotation.AsyncType;
import org.kar.archidata.dataAccess.DataAccess;
import org.kar.archidata.dataAccess.QueryCondition;
import org.kar.archidata.dataAccess.options.Condition;
import org.kar.archidata.exception.NotFoundException;
import org.kar.karso.model.Settings;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;

import jakarta.annotation.security.PermitAll;
import jakarta.annotation.security.RolesAllowed;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.PATCH;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.Context;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.SecurityContext;

@Path("/system_config")
@Produces(MediaType.APPLICATION_JSON)
public class SystemConfigResource {
	private static final Logger LOGGER = LoggerFactory.getLogger(SystemConfigResource.class);

	public static class GetSignUpAvailable {
		public boolean signup;

		public GetSignUpAvailable(final boolean availlable) {
			this.signup = availlable;
		}

		public GetSignUpAvailable() {
			this.signup = false;
		}
	}

	public SystemConfigResource() {}

	@GET
	@Path("is_sign_up_availlable")
	@PermitAll
	public GetSignUpAvailable isSignUpAvailable() throws Exception {
		final Settings set = DataAccess.getWhere(Settings.class,
				new Condition(new QueryCondition("key", "=", "SIGN_UP_ENABLE")));
		if (set == null) {
			throw new NotFoundException("Value does not exist");
		}
		final boolean availlable = "true".equalsIgnoreCase(set.value);
		final GetSignUpAvailable tmp = new GetSignUpAvailable(availlable);
		LOGGER.debug("mlkmlk {}", tmp.signup);
		return tmp;
	}

	@GET
	@Path("key/{key}")
	@RolesAllowed(value = { "USER", "ADMIN" })
	public Map<String, Object> getKey(@Context final SecurityContext sc, @PathParam("key") final String key)
			throws Exception {
		final Settings set = DataAccess.getWhere(Settings.class, new Condition(new QueryCondition("key", "=", key)));
		if (set == null) {
			throw new NotFoundException("Value does not exist");
		}
		final Map<String, Object> out = new HashMap<>();
		if ("BOOLEAN".equals(set.type)) {
			final boolean available = "true".equalsIgnoreCase(set.value);
			out.put("value", available);
		} else if ("NUMBER".equals(set.type)) {
			final double value = Double.parseDouble(set.value);
			out.put("value", value);
		} else {
			out.put("value", set.value);
		}
		return out;
	}

	@PATCH
	@Path("key/{key}")
	@RolesAllowed(value = { "ADMIN" })
	@Consumes(MediaType.APPLICATION_JSON)
	public void setKey(
			@Context final SecurityContext sc,
			@PathParam("key") final String key,
			@AsyncType(Object.class) final String jsonRequest) throws Exception {
		Settings res = null;
		try {
			res = DataAccess.getWhere(Settings.class, new Condition(new QueryCondition("key", "=", key)));
		} catch (final Exception e) {
			e.printStackTrace();
			final String result = "Can not find the Key: '" + key + "'";
			throw new NotFoundException(result);
		}
		final ObjectMapper mapper = new ObjectMapper();
		// Read the tree to filter injection of data:
		final JsonNode root = mapper.readTree(jsonRequest);
		final JsonNode value = root.findPath("value");

		res.value = value.asText();
		LOGGER.debug("Update value : {}", res.value);
		DataAccess.update(res, res.id, List.of("value"));
	}

}
