package org.kar.karso.filter;

import java.sql.Timestamp;
import java.time.Instant;
import java.util.Map;

import org.kar.archidata.dataAccess.DataAccess;
import org.kar.archidata.filter.AuthenticationFilter;
import org.kar.archidata.filter.PartRight;
import org.kar.archidata.model.UserByToken;
import org.kar.karso.api.UserResource;
import org.kar.karso.model.ApplicationToken;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import jakarta.annotation.Priority;
import jakarta.ws.rs.Priorities;
import jakarta.ws.rs.ext.Provider;

//@PreMatching
@Provider
@Priority(Priorities.AUTHENTICATION)
public class KarsoAuthenticationFilter extends AuthenticationFilter {
	private static final Logger LOGGER = LoggerFactory.getLogger(KarsoAuthenticationFilter.class);

	//curl  http://0.0.0.0:15080/karso/api/public_key/pem --output plop.txt -H "Authorization: Zota 1:U0sJM1m@-STSdfg4365fJOFUGbR4kFycBu1qGZPwf7gW6k2WWRBzTPUH7QutCgPw-SDss45_563sSDFdfg@dsf@456" --verbose

	public KarsoAuthenticationFilter() {
		super(UserResource.APPLICATION);
	}

	@Override
	protected UserByToken validateToken(final String authorization) throws Exception {
		if (authorization == null || authorization.length() < 25) {
			System.out.println("Application authentication too short '" + authorization + "'");
			return null;
		}
		final String[] elems = authorization.split(":");
		if (elems.length != 2) {
			System.out.println("Application authentication split error '" + authorization + "'");
			return null;
		}
		final Long indexToken = Long.parseLong(elems[0]);

		final ApplicationToken value = DataAccess.get(ApplicationToken.class, indexToken);
		if (value == null) {
			System.out.println("Application authentication can not find id '" + authorization + "'");
			return null;
		}
		// TODO: hash the sent token
		if (!value.token.equals(elems[1])) {
			System.out.println("Application authentication mismatch '" + authorization + "'");
			return null;
		}
		// TODO: check UTC !!!
		if (!value.endValidityTime.after(Timestamp.from(Instant.now()))) {
			System.out.println("Application authentication Time-out '" + authorization + "' " + value.endValidityTime
					+ " > " + Timestamp.from(Instant.now()));
			return null;
		}
		// ----------------------------------
		// -- All is good !!!
		// ----------------------------------
		// We are in transition phase the user element will be removed
		final UserByToken userByToken = new UserByToken();
		userByToken.id = value.id;
		userByToken.name = value.name;
		userByToken.parentId = value.parentId;
		userByToken.type = UserByToken.TYPE_APPLICATION;
		// TODO: Manage the retrieve of specific rights ...
		userByToken.right.put(UserResource.APPLICATION, Map.of("APPLICATION", PartRight.READ_WRITE));
		return userByToken;
	}
}
