package org.kar.karso.migration;

import java.util.List;

import org.kar.archidata.api.DataResource;
import org.kar.archidata.dataAccess.DBAccess;
import org.kar.archidata.dataAccess.addOnSQL.AddOnManyToMany;
import org.kar.archidata.externalRestApi.AnalyzeApi;
import org.kar.archidata.externalRestApi.TsGenerateApi;
import org.kar.archidata.filter.PartRight;
import org.kar.archidata.migration.MigrationSqlStep;
import org.kar.archidata.model.token.JwtToken;
import org.kar.karso.api.ApplicationResource;
import org.kar.karso.api.ApplicationTokenResource;
import org.kar.karso.api.Front;
import org.kar.karso.api.PublicKeyResource;
import org.kar.karso.api.RightResource;
import org.kar.karso.api.SystemConfigResource;
import org.kar.karso.api.UserResource;
import org.kar.karso.model.Application;
import org.kar.karso.model.ApplicationToken;
import org.kar.karso.model.Right;
import org.kar.karso.model.RightDescription;
import org.kar.karso.model.Settings;
import org.kar.karso.model.UserAuth;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class Initialization extends MigrationSqlStep {
	private static final Logger LOGGER = LoggerFactory.getLogger(Initialization.class);

	public static final int KARSO_INITIALISATION_ID = 1;

	public static final List<Class<?>> CLASSES_BASE = List.of(Settings.class, UserAuth.class, Application.class,
			ApplicationToken.class, RightDescription.class, Right.class);

	// created object
	private Application app = null;
	private UserAuth user = null;

	private RightDescription rightDescription;

	@Override
	public String getName() {
		return "Initialization";
	}

	public static void generateObjects() throws Exception {
		LOGGER.info("Generate APIs");
		final List<Class<?>> listOfResources = List.of(Front.class, DataResource.class, ApplicationResource.class,
				ApplicationTokenResource.class, PublicKeyResource.class, RightResource.class, UserResource.class,
				SystemConfigResource.class);
		final AnalyzeApi api = new AnalyzeApi();
		api.addAllApi(listOfResources);
		api.addModel(JwtToken.class);
		TsGenerateApi.generateApi(api, "../front/src/back-api/");
		LOGGER.info("Generate APIs (DONE)");
	}

	@Override
	public void generateStep() throws Exception {
		for (final Class<?> clazz : CLASSES_BASE) {
			addClass(clazz);
		}

		addAction((final DBAccess da) -> {
			final Application app = new Application();
			//app.id = 1L;
			app.name = "karso";
			app.description = "Root SSO interface";
			app.redirect = "https://atria-soft.org/karso/sso";
			app.redirectDev = "http://localhost:4003/karso/sso";
			app.notification = "";
			app.ttl = 666;
			this.app = da.insert(app);
		});
		// default admin: "karadmin" password: "adminA@666"
		addAction((final DBAccess da) -> {
			final UserAuth user = new UserAuth();
			//user.id = 1L;
			user.login = "karadmin";
			user.password = UserResource.getSHA512("adminA@666");
			user.email = "admin@admin.ZZZ";
			this.user = da.insert(user);
		});
		addAction((final DBAccess da) -> {
			AddOnManyToMany.addLink(da, UserAuth.class, this.user.id, "application", this.app.id);
		});
		addAction((final DBAccess da) -> {
			final Settings settings = new Settings();
			settings.key = "SIGN_UP_ENABLE";
			settings.right = "rwr-r-";
			settings.type = "BOOLEAN";
			settings.value = "false";
			da.insert(settings);
			settings.key = "SIGN_IN_ENABLE";
			settings.right = "rwr-r-";
			settings.type = "BOOLEAN";
			settings.value = "true";
			da.insert(settings);
			settings.key = "SIGN_UP_FILTER";
			settings.right = "rw----";
			settings.type = "STRING";
			settings.value = ".*";
			da.insert(settings);
			settings.key = "EMAIL_VALIDATION_REQUIRED";
			settings.right = "rwr-r-";
			settings.type = "BOOLEAN";
			settings.value = "false";
			da.insert(settings);
		});
		addAction((final DBAccess da) -> {
			final RightDescription rightDescription = new RightDescription();
			rightDescription.applicationId = this.app.id;
			rightDescription.key = "ADMIN";
			rightDescription.title = "Administrator";
			rightDescription.description = "Full administrator Right";
			this.rightDescription = da.insert(rightDescription);
		});
		addAction((final DBAccess da) -> {
			final Right right = new Right();
			right.applicationId = this.app.id;
			right.userId = this.user.id;
			right.rightDescriptionId = this.rightDescription.id;
			right.value = PartRight.READ_WRITE;
			da.insert(right);
		});
		// we generate an offset to permit to manage some generic upgrade in the future...
		addAction("""
				ALTER TABLE `application` AUTO_INCREMENT = 1000;
				""", "mysql");
		addAction("""
				ALTER TABLE `user` AUTO_INCREMENT = 1000;
				""", "mysql");
		addAction("""
				ALTER TABLE `settings` AUTO_INCREMENT = 1000;
				""", "mysql");
		addAction("""
				ALTER TABLE `right` AUTO_INCREMENT = 1000;
				""", "mysql");
		addAction("""
				ALTER TABLE `rightDescription` AUTO_INCREMENT = 1000;
				""", "mysql");
		display();
	}

	public static void dropAll(final DBAccess da) {
		for (final Class<?> element : CLASSES_BASE) {
			try {
				da.drop(element);
			} catch (final Exception ex) {
				LOGGER.error("Fail to drop table !!!!!!");
				ex.printStackTrace();
			}
		}
	}

	public static void cleanAll(final DBAccess da) {
		for (final Class<?> element : CLASSES_BASE) {
			try {
				da.cleanAll(element);
			} catch (final Exception ex) {
				LOGGER.error("Fail to clean table !!!!!!");
				ex.printStackTrace();
			}
		}
	}
}
