package org.kar.karso.migration;

import java.util.List;

import org.kar.archidata.dataAccess.DBAccess;
import org.kar.archidata.dataAccess.options.AccessDeletedItems;
import org.kar.archidata.dataAccess.options.OverrideTableName;
import org.kar.archidata.migration.MigrationSqlStep;
import org.kar.archidata.tools.UuidUtils;
import org.kar.karso.migration.model.UUIDConversion;

public class Migration20240515 extends MigrationSqlStep {

	public static final int KARSO_INITIALISATION_ID = 1;

	@Override
	public String getName() {
		return "migration-2024-05-15: Update the link user application and the cover";
	}

	public Migration20240515() {

	}

	@Override
	public void generateStep() {
		// update migration update (last one)
		addAction("""
				ALTER TABLE `user_link_application` ADD `uuid` binary(16) AFTER `id`;
				""");
		addAction((final DBAccess da) -> {
			final List<UUIDConversion> datas = da.gets(UUIDConversion.class, new AccessDeletedItems(),
					new OverrideTableName("user_link_application"));
			for (final UUIDConversion elem : datas) {
				elem.uuid = UuidUtils.nextUUID();
			}
			for (final UUIDConversion elem : datas) {
				da.update(elem, elem.id, List.of("uuid"), new OverrideTableName("user_link_application"));
			}
		});
		addAction("""
				ALTER TABLE `user_link_application`
				CHANGE `id` `id` bigint;
				""");
		addAction("""
				ALTER TABLE `user_link_application` DROP PRIMARY KEY;
				""");
		addAction("""
				ALTER TABLE `user_link_application`
				CHANGE `uuid` `uuid` binary(16) DEFAULT (UUID_TO_BIN(UUID(), TRUE));
				""");
		addAction("""
				ALTER TABLE `user_link_application`
				ADD PRIMARY KEY `uuid` (`uuid`);
				""");

		addAction("""
				ALTER TABLE `user_link_application`
				DROP `id`;
				""");

		addAction("""
				DROP TABLE `user_link_cover`;
				""");

		addAction("""
				ALTER TABLE `user`
				ADD `covers` json DEFAULT NULL COMMENT 'List of Id of the specific covers' AFTER `removed`;
				""");

	}

}
