package org.kar.karso.migration;

import java.util.List;

import org.bson.types.ObjectId;
import org.kar.archidata.dataAccess.DBAccess;
import org.kar.archidata.dataAccess.options.AccessDeletedItems;
import org.kar.archidata.dataAccess.options.OverrideTableName;
import org.kar.archidata.filter.PartRight;
import org.kar.archidata.migration.MigrationSqlStep;
import org.kar.karso.migration.model.OIDConversion;
import org.kar.karso.model.Right;

public class Migration20250204 extends MigrationSqlStep {

	public static final int KARSO_INITIALISATION_ID = 1;

	@Override
	public String getName() {
		return "migration-2025-02-04: mograte native id as ObjectId";
	}

	@Override
	public void generateStep() {
		// update migration update (last one)
		addAction("""
				ALTER TABLE `user_link_application` ADD `_id` binary(12) AFTER `uuid`;
				""");
		addAction((final DBAccess da) -> {
			final List<OIDConversion> datas = da.gets(OIDConversion.class, new AccessDeletedItems(),
					new OverrideTableName("user_link_application"));
			for (final OIDConversion elem : datas) {
				elem._id = new ObjectId();
			}
			for (final OIDConversion elem : datas) {
				da.update(elem, elem.uuid, List.of("_id"), new OverrideTableName("user_link_application"));
			}
		});
		addAction("""
				ALTER TABLE `user_link_application`
				CHANGE `uuid` `uuid` binary(16);
				""");
		addAction("""
				ALTER TABLE `user_link_application` DROP PRIMARY KEY;
				""");
		addAction("""
				ALTER TABLE `user_link_application`
				CHANGE `_id` `_id` binary(12) NOT NULL;
				""");
		addAction("""
				ALTER TABLE `user_link_application`
				ADD PRIMARY KEY `_id` (`_id`);
				""");
		addAction("""
				ALTER TABLE `user_link_application`
				DROP `uuid`;
				""");
		addAction("""
				ALTER TABLE `user`
				DROP `admin`;
				""");
		addAction("""
				ALTER TABLE `user`
				DROP `removed`;
				""");
		addAction("""
				ALTER TABLE `user` ADD `blockedReason` varchar(512) AFTER `blocked`;
				""");
		addAction("""
				ALTER TABLE `right`
				DROP `value`;
				""");
		addAction("""
				ALTER TABLE `right`  ADD `value` JSON NOT NULL AFTER `rightDescriptionId`;
				""");
		addAction((final DBAccess da) -> {
			final List<Right> datas = da.gets(Right.class, new AccessDeletedItems());
			for (final Right elem : datas) {
				elem.value = PartRight.READ_WRITE;
			}
			for (final Right elem : datas) {
				da.update(elem, elem.id, List.of("value"));
			}
		});
	}

}
