package org.kar.karso.model;

import java.nio.charset.StandardCharsets;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.time.ZoneOffset;
import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;

import org.kar.archidata.checker.CheckJPA;

import com.fasterxml.jackson.annotation.JsonInclude;

import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Pattern;
import jakarta.validation.constraints.Size;

@JsonInclude(JsonInclude.Include.NON_NULL)
public class DataGetToken {
	@NotNull
	@Size(min = 3, max = 128)
	@Pattern(regexp = "^[a-zA-Z0-9\\-_ \\.@]+$")
	public String login;
	@NotNull
	@Size(min = 2, max = 2)
	@Pattern(regexp = "^v1$")
	public String method;
	@NotNull
	@Size(min = 20, max = 64)
	@Pattern(regexp = "^\\d{4}\\-\\d{2}\\-\\d{2}T\\d{2}:\\d{2}:\\d{2}(\\.\\d{1,9})+.*$")
	public String time;
	@NotNull
	@Size(min = 128, max = 128)
	@Pattern(regexp = "^[a-zA-Z0-9]{128}$")
	public String password;

	public static class DataGetTokenChecker extends CheckJPA<DataGetToken> {
		public DataGetTokenChecker() {
			super(DataGetToken.class);
		}
	}

	public DataGetToken(final String login, final String password, final String time, final String method) {
		this.method = method;
		this.login = login;
		this.time = time;
		this.password = password;
	}

	public DataGetToken() {

	}

	public static String sha512(final String passwordToHash) { //, String salt){
		String generatedPassword = null;
		try {
			final MessageDigest md = MessageDigest.getInstance("SHA-512");
			//md.update(salt.getBytes(StandardCharsets.UTF_8));
			final byte[] bytes = md.digest(passwordToHash.getBytes(StandardCharsets.UTF_8));
			final StringBuilder sb = new StringBuilder();
			for (final byte element : bytes) {
				sb.append(Integer.toString((element & 0xff) + 0x100, 16).substring(1));
			}
			generatedPassword = sb.toString();
		} catch (final NoSuchAlgorithmException e) {
			e.printStackTrace();
		}
		return generatedPassword;
	}

	public static DataGetToken generate(final String login, final String password) {
		return generate(login, password, ZonedDateTime.now(ZoneOffset.UTC).format(DateTimeFormatter.ISO_INSTANT));
	}

	public static DataGetToken generate(final String login, final String password, final String time) {
		return generate(login, password, time, "v1");
	}

	public static DataGetToken generate(
			final String login,
			final String password,
			final String time,
			final String method) {
		return generateSha(login, sha512(password), time, method);
	}

	public static DataGetToken generateSha(
			final String login,
			final String password,
			final String time,
			final String method) {
		return new DataGetToken(login, sha512("login='" + login + "';pass='" + password + "';date='" + time + "'"),
				time, method);
	}
}
