package org.kar.karso.model;

import java.sql.Timestamp;
import java.util.List;

import org.kar.archidata.annotation.DataIfNotExists;
import org.kar.archidata.checker.CheckJPA;
import org.kar.archidata.model.User;

import com.fasterxml.jackson.annotation.JsonInclude;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.annotation.Nullable;
import jakarta.persistence.Column;
import jakarta.persistence.ManyToMany;
import jakarta.persistence.Table;
import jakarta.validation.constraints.Pattern;
import jakarta.validation.constraints.Size;
import jakarta.ws.rs.DefaultValue;

@Table(name = "user")
@DataIfNotExists
@JsonInclude(JsonInclude.Include.NON_NULL)
public class UserAuth extends User {
	@Column(length = 128, nullable = false)
	@Size(min = 128, max = 128)
	@Pattern(regexp = "^[a-zA-Z0-9]{128}$")
	@Nullable
	public String password;
	/*
	@Column(length = 128)
	public String passwordChange; //!< When change a password, the new password is set in temporary area and wait the email validation
	@Column(length = 128)
	public String passwordValidation; //!< UniqueId to validate the new password
	 */
	@Column(length = 512, nullable = false)
	@Size(min = 5, max = 128)
	@Pattern(regexp = "^[a-zA-Z0-9\\-\\._]+@[a-zA-Z0-9\\-_]+\\.[a-zA-Z0-9]+$")
	public String email;
	public Timestamp emailValidate; // time of validation
	@Column(length = 512)
	@Size(min = 5, max = 128)
	@Pattern(regexp = "^[a-zA-Z0-9\\-\\._]+@[a-zA-Z0-9\\-_]+\\.[a-zA-Z0-9]+$")
	public String newEmail;
	@DefaultValue("'0'")
	@Column(nullable = false)
	public Boolean avatar = false;
	@Schema(description = "List of accessible application (if not set the application is not available)")
	@ManyToMany(targetEntity = Application.class)
	public List<Long> applications = null;

	public static class UserAuthChecker extends CheckJPA<UserAuth> {
		public UserAuthChecker() {
			super(UserAuth.class);
		}
	}

}
