package test.kar.karso;

import java.io.IOException;
import java.util.Map;

import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.MethodOrderer;
import org.junit.jupiter.api.Order;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestMethodOrder;
import org.junit.jupiter.api.extension.ExtendWith;
import org.kar.archidata.filter.PartRight;
import org.kar.archidata.filter.RightSafeCaster;
import org.kar.archidata.model.GetToken;
import org.kar.archidata.tools.ConfigBaseVariable;
import org.kar.archidata.tools.JWTWrapper;
import org.kar.archidata.tools.RESTApi;
import org.kar.karso.model.DataGetToken;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.nimbusds.jwt.JWTClaimsSet;

@ExtendWith(StepwiseExtension.class)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
public class TestBase {
	private final static Logger LOGGER = LoggerFactory.getLogger(TestBase.class);

	static WebLauncherTest webInterface = null;
	static RESTApi api = null;

	public void login(final String login, final String password) {
		try {
			final GetToken token = api.post(GetToken.class, "users/get_token", DataGetToken.generate(login, password));
			api.setToken(token.jwt);
		} catch (final Exception ex) {
			Assertions.fail("Can not get Authentication for '" + login + "' ==> " + ex.getMessage());
		}
	}

	public void loginAdmin() {
		login("karadmin", "adminA@666");
	}

	@BeforeAll
	public static void configureWebServer() throws Exception {
		ConfigureDb.configure();
		LOGGER.info("configure server ...");
		webInterface = new WebLauncherTest();
		webInterface.migrateDB();
		LOGGER.info("Start REST (BEGIN)");
		webInterface.process();
		LOGGER.info("Start REST (DONE)");
		api = new RESTApi(ConfigBaseVariable.apiAdress);
	}

	@AfterAll
	public static void stopWebServer() throws InterruptedException, IOException {
		LOGGER.info("Kill the web server");
		webInterface.stop();
		webInterface = null;
		ConfigureDb.clear();
	}

	@Order(3)
	@Test
	public void firstUserConnect() throws Exception {
		final GetToken result = api.post(GetToken.class, "users/get_token",
				DataGetToken.generate("karadmin", "adminA@666", "2025-15-25T22:32:23.252Z"));
		final String[] splitted = result.jwt.split("\\.");
		Assertions.assertEquals(3, splitted.length);
		final String authorization = result.jwt;
		LOGGER.debug(" validate token : " + authorization);
		// Note with local access we get the internal key of the system.
		final JWTClaimsSet ret = JWTWrapper.validateToken(authorization, "KarAuth", null);
		// check the token is valid !!! (signed and coherent issuer...
		Assertions.assertNotNull(ret);
		// check userID
		final String userUID = ret.getSubject();
		final long id = Long.parseLong(userUID);
		Assertions.assertEquals(1, id);
		final String name = (String) ret.getClaim("login");
		Assertions.assertEquals("karadmin", name);

		final Object rowRight = ret.getClaim("right");
		Assertions.assertNotNull(rowRight);
		final Map<String, Map<String, PartRight>> rights = RightSafeCaster.safeCastAndTransform(ret.getClaim("right"));
		// Check if the element contain the basic keys:
		Assertions.assertEquals(rights.size(), 1);
		Assertions.assertTrue(rights.containsKey("karso"));
		final Map<String, PartRight> applRight = rights.get("karso");
		//logger.error("full right: {}", applRight);
		Assertions.assertEquals(applRight.size(), 2);
		Assertions.assertTrue(applRight.containsKey("ADMIN"));
		Assertions.assertEquals(PartRight.READ_WRITE, applRight.get("ADMIN"));
		Assertions.assertTrue(applRight.containsKey("USER"));
		Assertions.assertEquals(PartRight.READ_WRITE, applRight.get("USER"));

		//logger.debug("request user: '{}' right: '{}' row='{}'", userUID, applRight, rowRight);

		//Assertions.assertEquals("eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9", splitted[0]);
		//Assertions.assertEquals("eyJzdWIiOiIwIiwiYXBwbGljYXRpb24iOiJrYXJzbyIsImlzcyI6IkthckF1dGgiLCJyaWdodCI6eyJrYXJzbyI6eyJBRE1JTiI6dHJ1ZSwiVVNFUiI6dHJ1ZX19LCJsb2dpbiI6ImthcmFkbWluIiwiZXhwIjoxNjg0MTk5MTkzLCJpYXQiOjE2ODI3NTU0MjV9", splitted[1]);
		// TODO ... Assertions.assertEquals("????", splitted[2]);
	}

	@Order(5)
	@Test
	public void testMeWithToken() throws Exception {
		loginAdmin();
		final String result = api.get(String.class, "users/me");
		Assertions.assertEquals("{\"id\":1,\"login\":\"karadmin\"}", result);

	}

}
