package test.kar.karso;

import java.io.IOException;
import java.util.List;

import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.MethodOrderer;
import org.junit.jupiter.api.Order;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestMethodOrder;
import org.junit.jupiter.api.extension.ExtendWith;
import org.kar.archidata.exception.RESTErrorResponseException;
import org.kar.archidata.model.GetToken;
import org.kar.archidata.tools.ConfigBaseVariable;
import org.kar.archidata.tools.RESTApi;
import org.kar.karso.model.DataGetToken;
import org.kar.karso.model.UserAuthGet;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@ExtendWith(StepwiseExtension.class)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
public class TestUsers {
	private final static Logger LOGGER = LoggerFactory.getLogger(TestUsers.class);
	public final static String ENDPOINT_NAME = "users/";

	static WebLauncherTest webInterface = null;
	static RESTApi api = null;

	private static long idTest;

	@BeforeAll
	public static void configureWebServer() throws Exception {
		ConfigureDb.configure();
		LOGGER.info("configure server ...");
		webInterface = new WebLauncherTest();
		webInterface.migrateDB();
		LOGGER.info("Start REST (BEGIN)");
		webInterface.process();
		LOGGER.info("Start REST (DONE)");
		api = new RESTApi(ConfigBaseVariable.apiAdress);
		final GetToken result = api.post(GetToken.class, "users/get_token",
				DataGetToken.generate("karadmin", "adminA@666"));
		api.setToken(result.jwt);
	}

	@AfterAll
	public static void stopWebServer() throws IOException {
		LOGGER.info("Kill the web server");
		webInterface.stop();
		webInterface = null;
		ConfigureDb.clear();
	}

	@Order(1)
	@Test
	public void getsValue() throws RESTErrorResponseException, IOException, InterruptedException {
		final List<UserAuthGet> listUsers = api.gets(UserAuthGet.class, TestUsers.ENDPOINT_NAME);
		Assertions.assertNotNull(listUsers);
		Assertions.assertEquals(1, listUsers.size());
		Assertions.assertEquals(1, listUsers.get(0).id);
		Assertions.assertEquals(false, listUsers.get(0).blocked);
		Assertions.assertEquals(false, listUsers.get(0).avatar);
		Assertions.assertEquals("karadmin", listUsers.get(0).login);
		Assertions.assertEquals("admin@admin.ZZZ", listUsers.get(0).email);
	}
}
