/**
 * Interface of the server (auto-generated code)
 */
import {
	HTTPMimeType,
	HTTPRequestModel,
	RESTConfig,
	RESTRequestJson,
	RESTRequestVoid,
} from "../rest-tools";

import { z as zod } from "zod"
import {
	ApplicationToken,
	CreateTokenRequestWrite,
	Integer,
	Long,
	ZodApplicationToken,
	isApplicationToken,
} from "../model";

export namespace ApplicationTokenResource {

	export function create({
			restConfig,
			params,
			data,
		}: {
		restConfig: RESTConfig,
		params: {
			applicationId: Long,
		},
		data: CreateTokenRequestWrite,
	}): Promise<ApplicationToken> {
		return RESTRequestJson({
			restModel: {
				endPoint: "/application_token/{applicationId}/create",
				requestType: HTTPRequestModel.POST,
				contentType: HTTPMimeType.JSON,
				accept: HTTPMimeType.JSON,
			},
			restConfig,
			params,
			data,
		}, isApplicationToken);
	};

	export const ZodGetsTypeReturn = zod.array(ZodApplicationToken);
	export type GetsTypeReturn = zod.infer<typeof ZodGetsTypeReturn>;
	
	export function isGetsTypeReturn(data: any): data is GetsTypeReturn {
		try {
			ZodGetsTypeReturn.parse(data);
			return true;
		} catch (e: any) {
			console.log(`Fail to parse data type='ZodGetsTypeReturn' error=${e}`);
			return false;
		}
	}

	export function gets({
			restConfig,
			params,
		}: {
		restConfig: RESTConfig,
		params: {
			applicationId: Long,
		},
	}): Promise<GetsTypeReturn> {
		return RESTRequestJson({
			restModel: {
				endPoint: "/application_token/{applicationId}",
				requestType: HTTPRequestModel.GET,
				accept: HTTPMimeType.JSON,
			},
			restConfig,
			params,
		}, isGetsTypeReturn);
	};
	export function remove({
			restConfig,
			params,
		}: {
		restConfig: RESTConfig,
		params: {
			tokenId: Integer,
			applicationId: Long,
		},
	}): Promise<void> {
		return RESTRequestVoid({
			restModel: {
				endPoint: "/application_token/{applicationId}/{tokenId}",
				requestType: HTTPRequestModel.DELETE,
				contentType: HTTPMimeType.TEXT_PLAIN,
			},
			restConfig,
			params,
		});
	};
}
