import { createBrowserHistory } from 'history';
import {
  unstable_HistoryRouter as HistoryRouter,
  Navigate,
  Route,
  Routes,
} from 'react-router-dom';

import { Error404 } from '@/errors';
import { HelpPage } from '@/scene/home/HelpPage';
import { HomePage } from '@/scene/home/HomePage';
import { useHasRight } from '@/service/session';

import { ManageAccountPage } from './account/ManageAccountPage';
import { SignInDonePage } from './connection/SignInDonePage';
import { SignInPage } from './connection/SignInPage';
import { SignOutPage } from './connection/SignOutPage';
import { SettingsPage } from './home/SettingsPage';

export const AppRoutes = () => {
  const { isReadable } = useHasRight('USER');
  return (
    <HistoryRouter
      // @ts-expect-error
      history={createBrowserHistory({ window })}
      basename="/karso"
    >
      <Routes>
        {isReadable ? (
          <>
            <Route path="/" element={<Navigate to="home" replace />} />
            <Route path="/home/*" element={<HomePage />} />
            {/* Connection page after SSO */}
            <Route
              path="signin/:applicationName/:applicationData/*"
              element={<SignInDonePage />}
            />
            <Route
              path="signin/:applicationName/*"
              element={<SignInDonePage />}
            />
            <Route path="sso/*" element={<Navigate to="home" replace />} />
            <Route path="signout/*" element={<SignOutPage />} />
            <Route path="manage-account/*" element={<ManageAccountPage />} />
            <Route path="help" element={<HelpPage />} />
            <Route path="settings" element={<SettingsPage />} />
            <Route path="app" element={<HomePage />} />
            <Route path="*" element={<Error404 />} />
          </>
        ) : (
          <>
            <Route path="*" element={<SignInPage />} />
          </>
        )}
      </Routes>
    </HistoryRouter>
  );
};
