import { useEffect } from 'react';

import { Box, Flex, Image, Text } from '@chakra-ui/react';
import { useParams } from 'react-router-dom';

import avatar from '@/assets/images/avatar_generic.svg';
import { PageLayout } from '@/components/Layout/PageLayout';
import { TopBar } from '@/components/TopBar/TopBar';
import { ApplicationService } from '@/service/application';

export const SignInDonePage = () => {
  const { applicationName, applicationData } = useParams();
  const { transferToApplication } = ApplicationService.useTransferApplication();

  useEffect(() => {
    transferToApplication(applicationName ?? '', applicationData);
  }, []);
  return (
    <>
      <TopBar title="Login" />
      <PageLayout>
        <Flex marginX="auto" width="full" height="90%" direction="column">
          <Box
            bg="white"
            padding="30px"
            shadow="md"
            width="400px"
            margin="auto"
            background={{ _light: 'gray.50', _dark: 'gray.800' }}
          >
            <Text
              width="100%"
              textAlign="center"
              fontWeight="bold"
              fontSize="25px"
            >
              Connected
            </Text>
            <Image
              marginX="auto"
              marginY="10px"
              src={avatar}
              width="128px"
              height="128px"
              borderRadius="100%"
            />

            <Flex align="center" justify="center" direction="column">
              <Text>Connection done...</Text>
              {applicationName && (
                <Text>Will redirect to: {applicationName}</Text>
              )}
            </Flex>
          </Box>
        </Flex>
      </PageLayout>
    </>
  );
};
