import { useState } from 'react';

import { UserResource } from '@/back-api';
import { toaster, toasterAPIError } from '@/components/ui/toaster';
import { useSessionService } from '@/service/session';
//import { useSessionContext } from '@/context/SessionContext';
import { getRestConfig } from '@/utils/http';
import { sha512 } from '@/utils/sha512';

export const useLogin = () => {
  const [isConnectionLoading, setIsConnectionLoading] =
    useState<boolean>(false);
  const [lastError, setLastError] = useState<string>('');
  const { setToken, clearToken } = useSessionService();

  /**
   * Log-in with a clear password
   * @param login The user's login identifier (username or email address)
   * @param password The user's plain-text password
   * @returns promise on connection
   */
  const connect = (login: string, password: string) => {
    console.log(`call connect`);
    clearToken();
    setIsConnectionLoading(true);
    setLastError('');
    const currentDate: string = new Date().toISOString();
    const data = {
      login,
      method: 'v1',
      time: currentDate,
      // we mix the password to be sure that it can not be used an other time ...
      password: sha512(
        `login='${login}';pass='${sha512(password)}';date='${currentDate}'`
      ),
    };
    console.log(`call backend : ${JSON.stringify(data, null, 2)}`);
    UserResource.getToken({
      restConfig: getRestConfig(),
      data,
    })
      .then((response) => {
        setToken(response.jwt);
        toaster.create({
          title: 'Connection done',
          description: `Welcome, ${login}!`,
        });
        setIsConnectionLoading(false);
      })
      .catch(() => {
        toaster.create({
          title: 'Connection fail',
          description: `Fail to connect with identification: '${login}'`,
        });
        setLastError('The connection Fail');
        setIsConnectionLoading(false);
      });
  };
  return { connect, lastError, isConnectionLoading };
};
