import { Center, Flex, HStack, Text } from '@chakra-ui/react';
import { LuCrown } from 'react-icons/lu';

import { Application } from '@/back-api';
import { PageLayout } from '@/components/Layout/PageLayout';
import { TopBar } from '@/components/TopBar/TopBar';
import { useColorModeValue } from '@/components/ui/color-mode';
import { ApplicationService } from '@/service/application';

export const HomePage = () => {
  const { transferToApplication } = ApplicationService.useTransferApplication();
  const onSelectItem = (data: Application) => {
    transferToApplication(data.name ?? '');
    //window.location.href = data.redirect;
  };
  const { data: dataApplication } = ApplicationService.useGets();
  console.log(`ppp: ${JSON.stringify(dataApplication, null, 2)}`);
  return (
    <>
      <TopBar title="Home" />
      <PageLayout>
        <HStack
          wrap="wrap"
          gap="20px"
          marginX="auto"
          padding="20px"
          justify="center"
        >
          {dataApplication?.map((data) => (
            <Flex
              align="flex-start"
              width="200px"
              height="190px"
              border="1px"
              borderColor="brand.900"
              backgroundColor={useColorModeValue('#FFFFFF88', '#00000088')}
              key={data.id}
              padding="5px"
              as="button"
              _hover={{
                boxShadow: 'outline-over',
                bgColor: useColorModeValue('#FFFFFFF7', '#000000F7'),
              }}
              onClick={() => onSelectItem(data)}
            >
              <Flex direction="column" width="full" height="full">
                <Center height="full">
                  <LuCrown style={{ width: '100px', height: '100px' }} />
                </Center>
                <Center>
                  <Text
                    fontSize="25px"
                    fontWeight="bold"
                    textTransform="uppercase"
                    userSelect="none"
                  >
                    {data.name}
                  </Text>
                </Center>
              </Flex>
            </Flex>
          ))}
        </HStack>
      </PageLayout>
    </>
  );
};
