import {
  ApplicationToken,
  ApplicationTokenResource,
  CreateTokenRequestWrite,
  Integer,
  Long,
  RestErrorResponse,
} from '@/back-api';
import { useSessionService } from '@/service/session';
import { useQuery, useQueryCall, useQueryCallProps } from '@/utils/query';

export namespace ApplicationTokenService {
  export const useApplicationTokens = (applicationId: Long) => {
    const { getRestConfig } = useSessionService();
    return useQuery({
      queryFunction: () => {
        return ApplicationTokenResource.gets({
          restConfig: getRestConfig(),
          params: {
            applicationId,
          },
        });
      },
    });
  };

  export const useApplicationTokenCreate = (
    applicationId: Long,
    config: {
      config?: Omit<useQueryCallProps<ApplicationToken, any>, 'queryFunction'>;
    }
  ) => {
    const { getRestConfig } = useSessionService();
    const { call, ...rest } = useQueryCall<
      ApplicationToken,
      CreateTokenRequestWrite
    >({
      queryFunction: (inputData) => {
        return ApplicationTokenResource.create({
          restConfig: getRestConfig(),
          params: { applicationId },
          data: inputData,
        });
      },
      ...config,
    });
    return { createApplicationToken: call, ...rest };
  };

  export const useApplicationTokenRemove = (
    applicationId: Long,
    config: { config?: Omit<useQueryCallProps<void, any>, 'queryFunction'> }
  ) => {
    const { getRestConfig } = useSessionService();
    const { call, ...rest } = useQueryCall<
      void,
      {
        tokenId: Integer;
      }
    >({
      queryFunction: (inputData) => {
        return ApplicationTokenResource.remove({
          restConfig: getRestConfig(),
          params: {
            applicationId,
            ...inputData,
          },
        });
      },
      ...config,
    });
    return { removeApplicationToken: call, ...rest };
  };
}
