import { ReactNode, createContext, useContext, useMemo } from 'react';

import {
  RightGroup,
  SessionServiceProps,
  getRestConfig,
  useSessionServiceWrapped,
} from '@/service/session';

export type ServiceContextType = {
  session: SessionServiceProps;
};

export const ServiceContext = createContext<ServiceContextType>({
  session: {
    isConnected: false,
    setToken: (_token: string) => {},
    clearToken: () => {},
    hasReadRight: (_part: RightGroup) => false,
    hasWriteRight: (_part: RightGroup) => false,
    getRestConfig: getRestConfig,
  },
});

export const useServiceContext = () => useContext(ServiceContext);

export const ServiceContextProvider = ({
  children,
}: {
  children: ReactNode;
}) => {
  const session = useSessionServiceWrapped();
  const contextObjectData = useMemo(
    () => ({
      session,
    }),
    [session]
  );
  return (
    <ServiceContext.Provider value={contextObjectData}>
      {children}
    </ServiceContext.Provider>
  );
};
