/** @file
 * @author Edouard DUPIN
 * @copyright 2018, Edouard DUPIN, all right reserved
 * @license PROPRIETARY (see license file)
 */
import { BrowserModule } from '@angular/platform-browser';
import { NgModule, CUSTOM_ELEMENTS_SCHEMA, NO_ERRORS_SCHEMA } from '@angular/core';
import { RouterModule } from '@angular/router';
import { HttpClientModule } from '@angular/common/http';
import { FormsModule, ReactiveFormsModule } from '@angular/forms'; // this is needed for dynamic selection of the select
import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';
import {
	SignInScene,
	SignUpScene,
	ValidateEmailScene,
	HomeScene,
	ErrorViewerScene,
	ForgotPasswordScene,
	HelpScene,
	SignOutScene,
	ChangePasswordScene,
	SettingsScene,
	HomeUnregisteredScene,
	ManageAccountsScene,
	ApplicationsScene,
	ApplicationEditScene,
	ApplicationUserEditScene,
	applicationUserRightEditScene,
} from 'base/scene';
import { CommonModule } from '@angular/common';

import { AdminUserService, ApplicationService, ApplicationTokenService, SettingsService } from 'base/service';
import { environment } from 'environments/environment';
import { KarCWModule } from '@kangaroo-and-rabbit/kar-cw';

@NgModule({
	declarations: [
		AppComponent,

		SignInScene,
		SignUpScene,
		SignOutScene,
		ValidateEmailScene,
		HomeScene,
		ErrorViewerScene,
		HelpScene,
		ForgotPasswordScene,
		SettingsScene,
		ChangePasswordScene,
		HomeUnregisteredScene,
		ManageAccountsScene,
		ApplicationsScene,
		ApplicationEditScene,
		ApplicationUserEditScene,
		applicationUserRightEditScene,
	],
	imports: [
		BrowserModule,
		RouterModule,
		AppRoutingModule,
		HttpClientModule,
		FormsModule,
		ReactiveFormsModule,
		CommonModule,
		KarCWModule,
	],
	// injectable element
	providers: [
		{ provide: 'ENVIRONMENT', useValue: environment },
		// application
		AdminUserService,
		ApplicationService,
		ApplicationTokenService,
		SettingsService,

	],
	exports: [
		AppComponent,
	],
	bootstrap: [AppComponent],
	schemas: [CUSTOM_ELEMENTS_SCHEMA, NO_ERRORS_SCHEMA],
})

export class AppModule { }
