/**
 * Interface of the server (auto-generated code)
 */
import {
	HTTPMimeType,
	HTTPRequestModel,
	RESTConfig,
	RESTRequestJson,
	RESTRequestVoid,
} from "../rest-tools";

import { z as zod } from "zod"
import {
	GetSignUpAvailable,
	isGetSignUpAvailable,
} from "../model";

export namespace SystemConfigResource {


	export const ZodGetKeyTypeReturn = zod.record(zod.string(), zod.any());
	export type GetKeyTypeReturn = zod.infer<typeof ZodGetKeyTypeReturn>;
	
	export function isGetKeyTypeReturn(data: any): data is GetKeyTypeReturn {
		try {
			ZodGetKeyTypeReturn.parse(data);
			return true;
		} catch (e: any) {
			console.log(`Fail to parse data type='ZodGetKeyTypeReturn' error=${e}`);
			return false;
		}
	}

	export function getKey({
			restConfig,
			params,
		}: {
		restConfig: RESTConfig,
		params: {
			key: string,
		},
	}): Promise<GetKeyTypeReturn> {
		return RESTRequestJson({
			restModel: {
				endPoint: "/system_config/key/{key}",
				requestType: HTTPRequestModel.GET,
				accept: HTTPMimeType.JSON,
			},
			restConfig,
			params,
		}, isGetKeyTypeReturn);
	};
	export function isSignUpAvailable({
			restConfig,
		}: {
		restConfig: RESTConfig,
	}): Promise<GetSignUpAvailable> {
		return RESTRequestJson({
			restModel: {
				endPoint: "/system_config/is_sign_up_availlable",
				requestType: HTTPRequestModel.GET,
				accept: HTTPMimeType.JSON,
			},
			restConfig,
		}, isGetSignUpAvailable);
	};
	export function setKey({
			restConfig,
			params,
			data,
		}: {
		restConfig: RESTConfig,
		params: {
			key: string,
		},
		data: object,
	}): Promise<void> {
		return RESTRequestVoid({
			restModel: {
				endPoint: "/system_config/key/{key}",
				requestType: HTTPRequestModel.PATCH,
				contentType: HTTPMimeType.JSON,
			},
			restConfig,
			params,
			data,
		});
	};
}
