/**
 * Interface of the server (auto-generated code)
 */
import { z as zod } from "zod";

import {ZodLong} from "./long";
import {ZodPartRight} from "./part-right";
import {ZodGenericDataSoftDelete, ZodGenericDataSoftDeleteWrite } from "./generic-data-soft-delete";

export const ZodRight = ZodGenericDataSoftDelete.extend({
	/**
	 * application-ID that have the reference of the right
	 */
	applicationId: ZodLong,
	/**
	 * user-ID 
	 */
	userId: ZodLong,
	/**
	 * rightDescription-ID of the right description
	 */
	rightDescriptionId: ZodLong,
	/**
	 * Value of the right
	 */
	value: ZodPartRight,

});

export type Right = zod.infer<typeof ZodRight>;

export function isRight(data: any): data is Right {
	try {
		ZodRight.parse(data);
		return true;
	} catch (e: any) {
		console.log(`Fail to parse data type='ZodRight' error=${e}`);
		return false;
	}
}
export const ZodRightWrite = ZodGenericDataSoftDeleteWrite.extend({
	/**
	 * application-ID that have the reference of the right
	 */
	applicationId: ZodLong.optional(),
	/**
	 * user-ID 
	 */
	userId: ZodLong.optional(),
	/**
	 * rightDescription-ID of the right description
	 */
	rightDescriptionId: ZodLong.optional(),
	/**
	 * Value of the right
	 */
	value: ZodPartRight.optional(),

});

export type RightWrite = zod.infer<typeof ZodRightWrite>;

export function isRightWrite(data: any): data is RightWrite {
	try {
		ZodRightWrite.parse(data);
		return true;
	} catch (e: any) {
		console.log(`Fail to parse data type='ZodRightWrite' error=${e}`);
		return false;
	}
}
