/** @file
 * @author Edouard DUPIN
 * @copyright 2018, Edouard DUPIN, all right reserved
 * @license PROPRIETARY (see license file)
 */

import { ChangeDetectorRef, Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { AdminUserService, ApplicationService } from 'base/service';
import { isNullOrUndefined, AsyncActionState, SettingsItem, SettingType } from '@kangaroo-and-rabbit/kar-cw';
import { Application, RightDescription } from 'back-api';


@Component({
	selector: 'application-user-right-edit',
	templateUrl: './application-user-right-edit.html',
	styleUrls: ['./application-user-right-edit.less'],
})
export class applicationUserRightEditScene implements OnInit {
	page = '';
	applicationId: number = undefined;
	userId: number = undefined;
	application: Application;
	rowRight: RightDescription[] = [];
	applicationName: string;
	userName: string;
	userRights: any = {};

	constructor(
		private applicationService: ApplicationService,
		private adminUserService: AdminUserService,
		private activatedRoute: ActivatedRoute,
		private cdr: ChangeDetectorRef,
	) { }


	ngOnInit() {
		this.applicationId = Number(this.activatedRoute.snapshot.paramMap.get('applicationId'));
		this.userId = Number(this.activatedRoute.snapshot.paramMap.get('userId'));
		let self = this;
		this.applicationService
			.get(this.applicationId)
			.then((response: Application) => {
				console.log(`??? get full response: ${JSON.stringify(response, null, 4)}`);
				self.applicationName = response.name;
				self.application = response;
				//this.configureEditInput();
			})
			.catch((error: any) => {
				console.log(`??? get ERROR response: ${JSON.stringify(error, null, 4)}`);
			});
		/* TODO:
		this.userService
			.get(this.userId)
			.then((response: UserModel) => {
				console.log(`??? get full response: ${JSON.stringify(response, null, 4)}`);
				self.userName = response.name;
				//this.configureEditInput();
			})
			.catch((error: any) => {
				console.log(`??? get ERROR response: ${JSON.stringify(error, null, 4)}`);
			});
		*/
		this.applicationService
			.getRights(this.applicationId)
			.then((response: RightDescription[]) => {
				console.log(`getRights   OK   response: ${JSON.stringify(response, null, 4)}`);
				self.rowRight = response;
				self.configureEditInput();
			})
			.catch((error: any) => {
				console.log(`getRights ERROR response: ${JSON.stringify(error, null, 4)}`);
			});

		this.adminUserService
			.getApplicationRights(this.userId, this.applicationId)
			.then((userRights: any) => {
				console.log(`getApplicationRights   OK   response: ${JSON.stringify(userRights, null, 4)}`);
				self.userRights = userRights;
				self.configureEditInput();
			})
			.catch((error: any) => {
				console.log(`getApplicationRights ERROR response: ${JSON.stringify(error, null, 4)}`);
			});
		// get all the user connected on it
		/*
		this.applicationService
			.getUserRight(this.applicationId, this.userId)
			.then((userListToFilter: object[]) => {
				console.log(`??? get full response: ${JSON.stringify(userListToFilter, null, 4)}`);
				self.adminUserService
					.getUsers()
					.then((response: any[]) => {
						console.log(`All user available for this application: ${JSON.stringify(response, null, 4)}`);
						self.users = [];
						self.notUsers = [];
						for (let iii = 0; iii < response.length; iii++) {
							if (response[iii].blocked === true) {
								continue;
							}
							if (userListToFilter.indexOf(response[iii].id) >= 0) {
								self.users.push(response[iii]);
							} else {
								self.notUsers.push(response[iii]);
							}
						}
					})
					.catch((error: any) => {
						console.log(`??? get ERROR response: ${JSON.stringify(error, null, 4)}`);
					});
			})
			.catch((error: any) => {
				console.log(`??? get ERROR response: ${JSON.stringify(error, null, 4)}`);
			});
		*/
	}
	editMenu: SettingsItem[] = undefined;

	// this permit to clear the input menu...
	configureEditInput() {
		console.log(`generate inputs: ${JSON.stringify(this.rowRight, null, 4)}`);
		const tmp = [];
		for (let iii = 0; iii < this.rowRight.length; iii++) {
			const elem = this.rowRight[iii];
			let value = undefined;
			if (!isNullOrUndefined(this.userRights[elem.key])) {
				value = this.userRights[elem.key];
			}
			tmp.push({
				type: SettingType.BOOLEAN,
				title: elem.title,
				description: elem.description,
				key: elem.key,
				value: value,
			});
		}
		console.log(`New menu: ${JSON.stringify(tmp, null, 4)}`);
		this.editMenu = tmp;
		this.cdr.detectChanges();
	}
	updateButtonDisabled: number | undefined = undefined;
	dataUpdate: { [key: string]: object; } = {}

	onEditState(value: number) {
		console.log(`changeState : ${JSON.stringify(value, null, 2)}`);
		this.updateButtonDisabled = value;
		// we do not change the main ref ==> notify angular that something have change and need to be re-render???
		this.cdr.detectChanges();
	}
	onEditValues(value: { [key: string]: object; }) {
		console.log(`onDeltaValues : ${JSON.stringify(value, null, 2)}`);
		this.dataUpdate = value;
		// we do not change the main ref ==> notify angular that something have change and need to be re-render???
		this.cdr.detectChanges();
	}
	updateState: string | boolean = undefined;
	/**
	 * Request the creation of a new application.
	 */
	onUpdate(): void {
		this.updateState = AsyncActionState.LOADING;
		let self = this;
		console.log(`update requested: : ${JSON.stringify(this.dataUpdate, null, 2)}`);
		this.adminUserService
			.updateApplicationRights(this.userId, this.applicationId, this.dataUpdate)
			.then((userRights: any[]) => {
				console.log(`getApplicationRights   OK   response: ${JSON.stringify(userRights, null, 4)}`);
				self.userRights = userRights;
				self.updateState = AsyncActionState.DONE;
				self.configureEditInput()
				setTimeout(() => {
					this.updateState = undefined;
				}, 3000);
			})
			.catch((error: any) => {
				console.log(`getApplicationRights ERROR response: ${JSON.stringify(error, null, 4)}`);
				self.updateState = AsyncActionState.FAIL;
				setTimeout(() => {
					self.updateState = undefined;
				}, 3000);
			});
	}

}
