/** @file
 * @author Edouard DUPIN
 * @copyright 2018, Edouard DUPIN, all right reserved
 * @license PROPRIETARY (see license file)
 */

import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { Location } from '@angular/common';
import { AdminUserService } from 'base/service';
import { UserService } from '@kangaroo-and-rabbit/kar-cw';

export function checkLoginValidity(value: string): boolean {
	let regexCheck = new RegExp('^[a-zA-Z0-9_\\.-]+$');
	if (regexCheck.test(value)) {
		return true;
	}
	return false;
}

export function checkEmailValidity(value: string): boolean {
	let regexCheck = new RegExp('^[a-zA-Z0-9_\\.@-]+@[a-zA-Z0-9_\\.-]+\\.[a-zA-Z]+$');
	if (regexCheck.test(value)) {
		return true;
	}
	return false;
}

export function checkPasswordValidity(value: string): boolean {
	let regexCheck = new RegExp('^[a-zA-Z0-9_\\.@ %:;,=}{\\?\\!\\*\\+\\(\\)\\[\\]\\|&#%~/\\\\\\<\\>-£€]+$');
	if (regexCheck.test(value)) {
		return true;
	}
	return false;
}

@Component({
	selector: 'app-forgot-password',
	templateUrl: './forgot-password.html',
	styleUrls: ['./forgot-password.less'],
})
export class ForgotPasswordScene implements OnInit {
	public loginOK: boolean = false;
	public loginHelp: string = '';
	public login: string = '';
	public loginButtonDisabled: boolean = true;
	public error: string = '';
	public loginType: string = 'Username/E-mail';

	public notARobot: boolean = true;

	constructor(
		private router: Router,
		private locate: Location,
		private userService: UserService,
		private adminUserService: AdminUserService
	) { }

	ngOnInit() { }

	updateButtonVisibility(): void {
		if (this.loginOK === true && this.notARobot === true) {
			this.loginButtonDisabled = false;
		} else {
			this.loginButtonDisabled = true;
		}
		this.error = '';
	}

	checkIAmNotARobot(newValue: boolean): void {
		this.notARobot = newValue;
		this.updateButtonVisibility();
	}
	/**
	 * Check the login writing rules
	 */
	checkLogin(newValue: string): void {
		console.error(`checkLogin: ${newValue}`);
		this.login = newValue;
		if (this.login === null) {
			this.loginOK = false;
			this.loginHelp = '';
			this.updateButtonVisibility();
			return;
		}
		if (this.login.length < 6) {
			this.loginOK = false;
			this.loginHelp = 'Need 6 characters';
			this.loginType = 'Username/E-mail';
			this.updateButtonVisibility();
			return;
		}
		if (checkLoginValidity(this.login) === true) {
			this.loginOK = true;
			this.loginHelp = '';
			this.loginType = 'Username';
		} else if (checkEmailValidity(this.login) === true) {
			this.loginOK = true;
			this.loginHelp = '';
			this.loginType = 'E-mail';
		} else {
			this.loginOK = false;
			this.loginHelp = 'Not valid: characters, numbers, "_-." and email format: you@example.com';
		}
		this.updateButtonVisibility();
	}

	onRetreive(): void {
		let self = this;
		this.adminUserService
			.retrievePassword(this.login)
			.then(() => {
				// go to the retreive page
				self.router.navigate(['retreive']);
			})
			.catch(() => {
				self.error = 'Wrong e-mail/login';
			});
	}
	onCancel(): void {
		this.locate.back();
	}
}
